;;; 50aumix-mode.el -- debian emacs setups for aumix-mode.

;; Copyright 2014, 2019 Kevin Ryde

;; This file is part of aumix-mode.
;;
;; aumix-mode is free software; you can redistribute it and/or modify it under
;; the terms of the GNU General Public License as published by the Free
;; Software Foundation; either version 3, or (at your option) any later
;; version.
;;
;; aumix-mode is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
;; more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.


(let ((dir (concat "/usr/share/"
                   (symbol-name debian-emacs-flavor)
                   "/site-lisp/aumix-mode")))

  (cond ((not (file-exists-p "/usr/share/emacs/site-lisp/aumix-mode/aumix-mode.el"))
         (message "aumix-mode removed but not purged, skipping setup"))

        ((not (file-exists-p (expand-file-name "aumix-mode.elc" dir)))
         ;; autoloads not available until install script succeeds, ignore until
         ;; then for the benefit of other byte compiling, such as emacsen-common
         ;; compiling 00debian-vars.el
         (message "aumix-mode not yet byte-compiled, skipping setup"))

        (t
         ;; debian-pkg-add-load-path-item as from debian 3.1 "sarge",
         ;; emacsen-common 1.4.14 of June 2002
         (debian-pkg-add-load-path-item dir)

         ;; with :load of aumix-mode.el to create its member variables
         (defgroup aumix-mode nil "Aumix Mode"
           :group  'multimedia
           :load   "aumix-mode")

         (autoload 'aumix "aumix-mode"
           "Run the aumix program in a buffer."
           t)  ;; interactive

         ;; autoloaded for the benefit of desktop.el saving an aumix-mode buffer
         (autoload 'aumix-mode "aumix-mode"
           "Major mode for running the aumix program.") ;; not interactive

         (put 'aumix-mode-switches 'risky-local-variable t))))
